package com.platform.yijia.controller;

import com.google.gson.Gson;
import com.platform.yijia.config.YiJiaRequest;
import com.platform.yijia.pojo.Coupon;
import com.platform.yijia.pojo.UserCoupon;
import com.platform.yijia.service.CouponService;
import com.platform.yijia.utils.CodeMsg;
import com.platform.yijia.utils.ResultData;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/*
 * <Title> CouponController </Title>
 * <Description> 优惠券 </Description>
 * @Author JK
 * @Date 2021年7月6日
 */
@Controller
@YiJiaRequest()
@CrossOrigin
@Api(tags = "优惠券")
public class CouponController {
    private static Logger logger =(Logger) LoggerFactory.getLogger(CouponController.class);

    @Resource
    private CouponService couponService;

    //获取优惠券信息
    @RequestMapping(value = "/selectCouponInfo", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取优惠券信息", httpMethod = "GET", notes = "获取优惠券信息")
    public String selectCouponInfo(@ApiParam(value = "优惠券ID", required = true) @RequestParam Integer id){
        Gson gson =new Gson();
        //返回结果集
        ResultData resultData = null;
        try {
            Coupon coupon = new Coupon();
            coupon.setId(id);
            Coupon couponInfo = couponService.selectCouponInfo(coupon);
            resultData = ResultData.success(couponInfo);
        }catch (Exception e){
            logger.error("获取优惠券错误信息：" + e.getMessage());
            resultData = ResultData.error(CodeMsg.SEARCH_FAIL);
        }
        return  gson.toJson(resultData);
    }

    //获取客户所拥有的优惠券
    @RequestMapping(value = "/selectUserCoupons", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取客户所拥有的优惠券", httpMethod = "GET", notes = "获取客户所拥有的优惠券")
    public String selectUserCoupons(@ApiParam(value = "油站ID", required = true) @RequestParam Integer stationId,
                                    @ApiParam(value = "用户unionId", required = true) @RequestParam String unionId){
        Gson gson =new Gson();
        //返回结果集
        ResultData resultData = null;
        try {
            UserCoupon userCoupon = new UserCoupon();
            userCoupon.setStationId(stationId);
            userCoupon.setUnionId(unionId);
            List<UserCoupon> userCoupons = couponService.selectUserCoupons(userCoupon);
            resultData = ResultData.success(userCoupons);
        }catch (Exception e){
            logger.error("获取客户所拥有的优惠券错误信息：" + e.getMessage());
            resultData = ResultData.error(CodeMsg.SEARCH_FAIL);
        }
        return  gson.toJson(resultData);
    }


}
